==> haskell-wai-websockets-3.0.1.2-354-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-1VxmvSxdUuaDE7jPoCADNs
key:                  wai-websockets-3.0.1.2-1VxmvSxdUuaDE7jPoCADNs
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  2c1795cd4f9bfd92fb3631ee4cb91e85
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-1VxmvSxdUuaDE7jPoCADNs
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-A8tt3kA3ht8BcsnLzy1cSk
    http-types-0.12.3-6SjaEFyZrR71uf1AqCfbdK
    network-3.1.2.7-GkGKOGJhtS7DhusgFes5fA transformers-0.5.6.2
    wai-3.2.3-Ec5IYfflqSc74IJaeojcpJ
    websockets-0.12.7.3-4F755Kq7gvMzKUFiylyd4

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-356-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-4V5Yp7EXe0AC9TZNQPmXKw
key:                  wai-websockets-3.0.1.2-4V5Yp7EXe0AC9TZNQPmXKw
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  19f27a470f2b7ec01514cc8afad58844
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-4V5Yp7EXe0AC9TZNQPmXKw
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-AxU2XVuOes5CFI4MXNB5c7
    http-types-0.12.3-HvT6bJuxvKDh0p4h5wana
    network-3.1.2.7-BfLNNWIREyL84biQKbgmoR transformers-0.5.6.2
    wai-3.2.3-6UnMYPOlhi1DIF1lvMiIkO
    websockets-0.12.7.3-3RORrnYGTQU3SiQPVwwnhX

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
